#!/bin/bash

if [ -e "certificate.pem" ]
then
        echo "certificate exsists, skipping creation"
else
	echo "certificate missing, creating"
	openssl genrsa -out key.pem 1024
	openssl req -new -key key.pem -out request.pem
	openssl x509 -req -days 9999 -in request.pem -signkey key.pem -out certificate.pem
	openssl pkcs8 -topk8 -outform DER -in key.pem -inform PEM -out key.pk8 -nocrypt
fi

rm -rf build/update
mkdir -p build/update
mkdir -p build/update/system/app
mkdir -p build/update/system/framework
mkdir -p build/update/META-INF/com/google/android
cp build/app-deodex/* build/update/system/app/
cp build/framework-deodex/* build/update/system/framework/
cp ./update-binary build/update/META-INF/com/google/android/update-binary

cat ./updater-header > build/update/META-INF/com/google/android/updater-script

for file in $(echo build/update/system/app/*.apk);
do
        filename=$(basename $file)
        extension=${filename##*.}
        filename=${filename%.*}

	echo "delete(\"/system/app/${filename}.odex\");" >> build/update/META-INF/com/google/android/updater-script
done

for file in $(echo build/update/system/framework/*.jar);
do
        filename=$(basename $file)
        extension=${filename##*.}
        filename=${filename%.*}

	echo "delete(\"/system/framework/${filename}.odex\");" >> build/update/META-INF/com/google/android/updater-script
done

cat ./updater-footer >> build/update/META-INF/com/google/android/updater-script
cd build/update/
zip -r ../update.zip *
cd -
java -jar signapk.jar certificate.pem key.pk8 build/update.zip update-signed.zip

rm build/update.zip
