#!/bin/bash

# adb path
export ANDROID_SDK="/Users/YOUR_USER_NAME/Downloads/android-sdk-mac_x86"
export ANDROID_NDK="/Users/YOUR_USER_NAME/Downloads/android-ndk-r7"
export PATH=$PATH:$ANDROID_SDK/platforms/android-10/tools:$ANDROID_SDK/platform-tools:$ANDROID_SDK/tools:$ANDROID_NDK/toolchains/arm-linux-androideabi-4.4.3/prebuilt/linux-x86:$AN$

echo "Galaxy S EI22 Deodexer by Andrew N Carr, based on:"
echo "SIMPLE DEODEXER by lowtraxx"
echo "--------------------------------------------------"
#echo "you will need to enter your su password, because some permissions have to be preserved"

# Cleanup
if [ -e "build" ] 
then
	echo "Cleaning up previous build"
	rm -rf build/temp
	rm -rf build/framework-deodex
	rm -rf build/app-deodex
else
	mkdir build
fi
mkdir build/temp
echo "Pulling the framework and app directories"
#adb pull /system/framework/ build/framework-pulled
#adb pull /system/app/ build/app-pulled

echo "-------------------------------"
echo "Starting deodexing of framework"
echo "-------------------------------"
mkdir build/framework-deodex
for file in $(echo build/framework-pulled/*.odex); 
do 
	#mkdir build/temp

	filename=$(basename $file)
	extension=${filename##*.}
	filename=${filename%.*}

	echo "Deodexing $(basename $file)"
	java -jar baksmali.jar -d build/framework-pulled -o build/temp -a 10 -x ${file} &> /dev/null
	RETVAL=$?
	if [ $RETVAL -ne 0 ]
	then
		echo -e "\t simple deodex of $(basename $file) failed"
		echo -e "\t trying alternate method for $(basename $file)"
		rm -rf build/temp/*
		java -jar baksmali.jar -d build/framework-pulled -c :core-junit.jar:framework.jar -o build/temp -a 10 -x ${file}
		RETVAL=$?
		if [ $RETVAL -ne 0 ]
		then
			echo "ERROR: second deodex attempt failed, halting"
			exit 1
		fi
	fi
	find build/temp -type f -exec sed -i -e 's/return-void-barrier/return-void/g' {} \;
	java -Xmx512M -jar smali.jar build/temp -a 10 -o build/classes.dex
	
	# Add the dex file to the jar	
	if [ -e "build/classes.dex" ]
	then
  		echo -e "\t adding classes.dex to jar"
  		cp build/framework-pulled/${filename}.jar build/temp/
		jar uf build/temp/${filename}.jar -C build/ classes.dex
		rm build/classes.dex
			echo -e "\t running zipalign..."
	${ANDROID_SDK}/tools/zipalign -f 4 build/temp/${filename}.jar build/framework-deodex/${filename}.jar
	else
		echo "classes.dex does not exist, halting"
		exit 1
	fi
	
	rm -rf build/temp/*
done

# Deodex for apps
mkdir build/app-deodex
#cp build/framework-deodex/* .
#cp build/framework-pulled/*.jar .

echo "--------------------------"
echo "Starting deodexing of apps"
echo "--------------------------"
for file in $(echo build/app-pulled/*.odex);
do 
	filename=$(basename $file)
	extension=${filename##*.}
	filename=${filename%.*}

	echo "Deodexing $(basename $file)"
	java -jar baksmali.jar -d build/framework-pulled -c :com.android.location.provider.jar:javax.obex.jar:bouncycastle.jar:com.google.android.maps.jar:twframework.jar:seccamera.jar  -o build/temp -a 10 -x ${file} 
	

	find build/temp -type f -exec sed -i -e 's/return-void-barrier/return-void/g' {} \;
	
	echo "  compiling classes.dex for ${filename}.apk"
	java -Xmx512M -jar smali.jar build/temp -a 10 -o build/classes.dex

	# If we can not find the clases.dex, then something went wrong, so halt.
	if [ -e "build/classes.dex" ]
	then
  		echo "  classes.dex exists, adding to ${filename}.apk"
		# Add the dex file to the apk
		cp build/app-pulled/${filename}.apk build/temp/
		#cd build
		zip -j build/temp/${filename}.apk build/classes.dex
		#cd -
		rm build/classes.dex	
	else
		echo "ERROR: classes.dex does not exist for $(basename $file), halting"
		exit 1
	fi
	echo "  Running zipalign..."
	${ANDROID_SDK}/tools/zipalign -f 4 build/temp/${filename}.apk build/app-deodex/${filename}.apk

	rm -rf build/temp/*

	#mv ${filename}.apk ../app-deodex/
done
